#########################
Download and installation
#########################

Installation from source
-------------------------

The package requires Python version 2.7 or newer. To build the
package from source, the Python header files and libraries must be
installed, as well as the core binaries. SMCP also requires the Python
extension modules `CVXOPT 1.1.7 <http://cvxopt.org>`_ or
later and `CHOMPACK 2.0 <http://cvxopt.github.io/chompack>`_ or later.

The entire source package is available `here <https://github.com/cvxopt/smcp>`_, and it includes
documentation, installation instructions, and examples.


Installation with pip
-------------------------

SMCP can be installed via pip using the following command:

.. code-block:: bash

	pip install smcp --user
